@@ -84,10 +84,6 @@ namespace FSpot {
 			get { return area_prepared; }
 		}
 
-		public string Path {
-			get { return uri.LocalPath; }
-		}
-
 		public Gdk.Pixbuf Pixbuf {
 			get { return pixbuf; }
 		}
@@ -117,13 +113,15 @@ namespace FSpot {
 			area_prepared = false;
 			damage = Gdk.Rectangle.Zero;
 
-			ImageFile img = ImageFile.Create (Path);
-			orientation = img.Orientation;
-
+			ImageFile img = ImageFile.Create (uri);
+			orientation = Accelerometer.GetViewOrientation (img.Orientation);
+			
 			try {
+				PixbufOrientation thumb_orientation = Accelerometer.GetViewOrientation (PixbufOrientation.TopLeft);
 				thumb = new Gdk.Pixbuf (ThumbnailGenerator.ThumbnailPath (uri));
+				thumb = PixbufUtils.TransformOrientation (thumb, thumb_orientation);
 			} catch (System.Exception e) {
-				FSpot.ThumbnailGenerator.Default.Request (uri.LocalPath, 0, 256, 256);	
+				//FSpot.ThumbnailGenerator.Default.Request (uri.ToString (), 0, 256, 256);	
 				if (!(e is GLib.GException)) 
 					System.Console.WriteLine (e.ToString ());
 			}
@@ -181,7 +179,7 @@ namespace FSpot {
 					// this can throw exceptions
 					loader.Close ();
 				}
-			} catch (System.Exception e) {
+			} catch (System.Exception) {
 				//System.Console.WriteLine (e.ToString ());
 				if (pixbuf != null)
 					pixbuf.Dispose ();
@@ -206,7 +204,7 @@ namespace FSpot {
 		{
 			Gdk.Rectangle area = damage;
 			
-			if (pixbuf != null && loader.Pixbuf != null && loader.Pixbuf != pixbuf)
+			if (pixbuf != null && loader.Pixbuf != null && loader.Pixbuf != pixbuf && damage != Gdk.Rectangle.Zero)
 				area = PixbufUtils.TransformAndCopy (loader.Pixbuf, pixbuf, orientation, damage);
 			
 			if (area.Width != 0 && area.Height != 0 && AreaUpdated != null)
@@ -353,11 +351,7 @@ namespace FSpot {
 				try {
 					len = stream.Read (buffer, 0, buffer.Length);
 					loader.Write (buffer, (ulong)len);
-				} catch (System.ObjectDisposedException od) {
-					len = -1;
-				} catch (GLib.GException e) {
-					System.Console.WriteLine (e.ToString ());
-					pixbuf = null;
+				} catch (Exception) {
 					len = -1;
 				}
 
@@ -393,7 +387,7 @@ namespace FSpot {
 			
 			if (thumb != null)
 				if (!ThumbnailGenerator.ThumbnailIsValid (thumb, uri))
-					FSpot.ThumbnailGenerator.Default.Request (Path, 0, 256, 256);
+					FSpot.ThumbnailGenerator.Default.Request (uri, 0, 256, 256);
 
 			area_prepared = true;			
 			if (AreaUpdated != null)
@@ -419,7 +413,7 @@ namespace FSpot {
 			// FIXME This should probably queue the
 			// thumbnail regeneration to a worker thread
 			if (validate_thumbnail && done_reading && pixbuf != null) {
-				PhotoLoader.ValidateThumbnail (Path, pixbuf);
+				PhotoLoader.ValidateThumbnail (uri, pixbuf);
 			}
 
 			if (Done != null)
