@@ -8,14 +8,16 @@ namespace FSpot {
 		protected BrowsablePointer item;
 		protected FSpot.Loupe loupe;
 		protected FSpot.Loupe sharpener;
-		
+
 		public PhotoImageView (IBrowsableCollection query)
 		{
 			loader = new FSpot.AsyncPixbufLoader ();
 			loader.AreaUpdated += HandlePixbufAreaUpdated;
 			loader.AreaPrepared += HandlePixbufPrepared;
 			loader.Done += HandleDone;
-			
+
+			Accelerometer.OrientationChanged += HandleOrientationChanged;
+
 			this.SizeAllocated += HandleSizeAllocated;
 			this.KeyPressEvent += HandleKeyPressEvent;
 			this.ScrollEvent += HandleScrollEvent;
@@ -61,6 +63,11 @@ namespace FSpot {
 			return this.Pixbuf;
 		}
 
+		public void HandleOrientationChanged (object sender)
+		{
+			Reload ();
+		}
+
 		public void Reload ()
 		{
 			if (!Item.IsValid)
@@ -95,6 +102,8 @@ namespace FSpot {
 			// pass the state and the write exception in the args
 			Gdk.Pixbuf prev = this.Pixbuf;
 			if (loader.Pixbuf == null) {
+				System.Exception ex = null;
+
 				// FIXME in some cases the image passes completely through the
 				// pixbuf loader without properly loading... I'm not sure what to do about this other
 				// than try to load the image one last time.
@@ -108,16 +117,17 @@ namespace FSpot {
 					} catch (System.Exception e) {
 						if (!(e is GLib.GException))
 							System.Console.WriteLine (e.ToString ());
+
+						ex = e;
 					}
 				}
 
-				if (this.Pixbuf == null)
-					this.Pixbuf = new Gdk.Pixbuf (PixbufUtils.ErrorPixbuf, 0, 0, 
-								      PixbufUtils.ErrorPixbuf.Width, 
-								      PixbufUtils.ErrorPixbuf.Height);
-
-				UpdateMinZoom ();
-				this.ZoomFit ();
+				if (this.Pixbuf == null) {
+					LoadErrorImage (ex);
+				} else {
+					UpdateMinZoom ();
+					this.ZoomFit ();
+				}
 			} else {
 				this.Pixbuf = loader.Pixbuf;
 
@@ -211,11 +221,13 @@ namespace FSpot {
 
 		private void PhotoItemChanged (BrowsablePointer item, BrowsablePointerChangedArgs args) 
 		{
+			System.Console.WriteLine ("item changed");
 			// If it is just the position that changed fall out
 			if (args != null && 
 			    args.PreviousItem != null &&
-			    Item.IsValid && 
-			    this.Item.Current.DefaultVersionUri == args.PreviousItem.DefaultVersionUri)
+			    Item.IsValid &&
+			    (args.PreviousIndex != item.Index) &&
+			    (this.Item.Current.DefaultVersionUri == args.PreviousItem.DefaultVersionUri))
 				return;
 
 			if (load_async) {
@@ -300,6 +312,16 @@ namespace FSpot {
 				scrolled.SetPolicy (Gtk.PolicyType.Automatic, Gtk.PolicyType.Automatic);
 		}
 		
+		private void HandleLoupeDestroy (object sender, EventArgs args)
+		{
+			if (sender == loupe)
+				loupe = null;
+
+			if (sender == sharpener)
+				sharpener = null;
+
+		}
+
 		[GLib.ConnectBefore]
 		private void HandleKeyPressEvent (object sender, Gtk.KeyPressEventArgs args)
 		{
@@ -362,14 +384,18 @@ namespace FSpot {
 				ZoomOut ();
 				break;
 			case Gdk.Key.s:
-				if (sharpener == null)
+				if (sharpener == null) {
 					sharpener = new Sharpener (this);
+					sharpener.Destroyed += HandleLoupeDestroy;
+				}
 
 				sharpener.Show ();
 				break;
 			case Gdk.Key.v:
-				if (loupe == null)
+				if (loupe == null) {
 					loupe = new Loupe (this);
+					loupe.Destroyed += HandleLoupeDestroy;
+				}
 
 				loupe.Show ();
 				break;
