@@ -156,7 +156,7 @@ public class Photo : DbItem, IComparable, FSpot.IBrowsableItem {
 
 	private string Path {
 		get {
-			return directory_path + "/" + name;
+			return System.IO.Path.Combine (directory_path, name);
 		}
 	}
 
@@ -603,8 +603,14 @@ public class PhotoStore : DbStore {
 
 	public static Pixbuf GenerateThumbnail (Uri uri)
 	{
-		Pixbuf thumbnail = null;
 		FSpot.ImageFile img = FSpot.ImageFile.Create (uri);
+		
+		return GenerateThumbnail (uri, img);
+	}
+
+	public static Pixbuf GenerateThumbnail (Uri uri, ImageFile img)
+	{
+		Pixbuf thumbnail = null;
 
 		if (img is FSpot.IThumbnailContainer) {
 			try {
@@ -730,7 +736,7 @@ public class PhotoStore : DbStore {
 		AddToCache (photo);
 		photo.Loaded = true;
 
-		thumbnail = GenerateThumbnail (UriList.PathToFileUri (newPath));		
+		thumbnail = GenerateThumbnail (UriList.PathToFileUri (newPath), img);		
 		EmitAdded (photo);
 
 		return photo;
@@ -1153,11 +1159,11 @@ public class PhotoStore : DbStore {
 	// Queries.
 	public Photo [] Query (Tag [] tags, DateTime start, DateTime end)
 	{
-		return Query (tags, new DateRange (start, end));
+		return Query (tags, null, new DateRange (start, end));
 	}
 	
 	public Photo [] Query (Tag [] tags) {
-		return Query (tags, null);
+		return Query (tags, null, null);
 	}
 
 	public Photo [] Query (string query)
@@ -1241,18 +1247,11 @@ public class PhotoStore : DbStore {
 		return Query (query_builder.ToString ());
 	}
 
-	public Photo [] Query (Tag [] tags, DateRange range)
+	public Photo [] Query (Tag [] tags, string extra_condition, DateRange range)
 	{
 		string query;
 
-		bool hide = true;
-		if (tags != null) {
-			foreach (Tag t in tags) {
-				if (tag_store.Hidden == null || t.Id == tag_store.Hidden.Id) 
-					hide = false;
-			}
-		} else
-			hide = tag_store.Hidden != null;
+		bool hide = (extra_condition == null);
 
 		// The SQL query that we want to construct is:
 		//
@@ -1264,9 +1263,10 @@ public class PhotoStore : DbStore {
 		//        photos.default_version_id
 		//                  FROM photos, photo_tags
 		//                  WHERE photos.id = photo_tags.photo_id
-		// 		          AND (photo_tags.tag_id = tag1
-		//			       OR photo_tags.tag_id = tag2
-		//                             OR photo_tags.tag_id = tag3 ...)
+		// 		                AND (photo_tags.tag_id = cat1tag1
+		//			            OR photo_tags.tag_id = cat1tag2 ) 
+		// 		                AND (photo_tags.tag_id = cat2tag1
+		//			            OR photo_tags.tag_id = cat2tag2 )
 		//                  GROUP BY photos.id
 		
 		StringBuilder query_builder = new StringBuilder ();
@@ -1311,6 +1311,16 @@ public class PhotoStore : DbStore {
 			if (!first)
 				query_builder.Append (")) ");
 		}
+
+		if (extra_condition != null) {
+			query_builder.Append (
+				String.Format (
+					"{0} {1} ",
+					(hide || range != null || (tags != null && tags.Length > 0)) ? " AND " : " WHERE ",
+					extra_condition
+				)
+			);
+		}
 		
 		query_builder.Append ("ORDER BY photos.time");
 		query = query_builder.ToString ();
