@@ -106,6 +106,7 @@ class PixbufUtils {
 		int max_width;
 		int max_height;
 		PixbufOrientation orientation;
+		int orig_width;
 
 		public AspectLoader (int max_width, int max_height) 
 		{
@@ -204,6 +205,33 @@ class PixbufUtils {
 		return result;
 	}
 		
+	static public void GetSize (string path, out int width, out int height)
+	{
+		Gdk.PixbufLoader loader = new Gdk.PixbufLoader ();
+		int orig_width = 0;
+		int orig_height = 0;
+		bool done = false;
+
+		loader.SizePrepared += delegate (object obj, SizePreparedArgs args) {
+			orig_width = args.Width;
+			orig_height = args.Height;
+			done = true;
+		};
+		
+		using (Stream stream = File.OpenRead (path)) {
+			byte [] data = new byte [4096];
+			int count;
+
+			while (((count = stream.Read (data, 0, data.Length)) > 0) && loader.Write (data, (ulong)count)) {
+				if (done)
+					break;
+			}
+		}
+		
+		width = orig_width;
+		height = orig_height;
+	}
+
 	static public Pixbuf LoadAtMaxSize (string path, int max_width, int max_height)
 	{
 #if true
@@ -430,10 +458,27 @@ class PixbufUtils {
 			exif_data = new Exif.ExifData ();
 
 		Gdk.Pixbuf image = PixbufUtils.LoadAtMaxSize (orig_path, size, size);
+
 		PixbufUtils.SaveJpeg (image, dest_path, 95, exif_data);
+		image.Dispose ();
 	}
 	
 
+	public static Pixbuf Flatten (Pixbuf pixbuf)
+	{
+		if (!pixbuf.HasAlpha)
+			return null;
+
+		Pixbuf flattened = new Pixbuf (Colorspace.Rgb, false, 8, pixbuf.Width, pixbuf.Height);
+		pixbuf.CompositeColor (flattened, 0, 0, 
+				       pixbuf.Width, pixbuf.Height, 
+				       0, 0, 1, 1, 
+				       InterpType.Bilinear,
+				       255, 0, 0, 2000, 0xffffff, 0xffffff);
+
+		return flattened;
+	}
+
 	[StructLayout(LayoutKind.Sequential)]
 	public unsafe struct FPixbufJpegMarker {
 		public int type;
@@ -446,6 +491,12 @@ class PixbufUtils {
 
 	public static void SaveJpeg (Pixbuf pixbuf, string path, int quality, Exif.ExifData exif_data)
 	{
+		Pixbuf temp = null;
+		if (pixbuf.HasAlpha) {
+			temp = Flatten (pixbuf);
+			pixbuf = temp;
+		}
+
 		// The DCF spec says thumbnails should be 160x120 always
 		Pixbuf thumbnail = ScaleToAspect (pixbuf, 160, 120);
 		byte [] thumb_data = Save (thumbnail, "jpeg", null, null);
@@ -484,6 +535,9 @@ class PixbufUtils {
 			
 		}
 
+		if (temp != null)
+			temp.Dispose ();
+		
 		if (result == false)
 			throw new System.Exception ("Error Saving File");
 	}
