@@ -257,12 +257,12 @@ public class UriList : ArrayList {
 }
 
 class GtkUtil {
-	public static void MakeMenuItem (Gtk.Menu menu, string l, EventHandler e)
+	public static Gtk.MenuItem MakeMenuItem (Gtk.Menu menu, string l, EventHandler e)
 	{
-		MakeMenuItem (menu, l, e, true);
+		return MakeMenuItem (menu, l, e, true);
 	}
 	
-	public static void MakeMenuItem (Gtk.Menu menu, string l, EventHandler e, bool enabled)
+	public static Gtk.MenuItem MakeMenuItem (Gtk.Menu menu, string l, EventHandler e, bool enabled)
 	{
 		Gtk.MenuItem i;
 		Gtk.StockItem item = Gtk.StockItem.Zero;
@@ -280,9 +280,11 @@ class GtkUtil {
 		
 		menu.Append (i);
 		i.Show ();
+
+        return i;
 	}
 	
-	public static void MakeMenuItem (Gtk.Menu menu, string label, string image_name, EventHandler e, bool enabled)
+	public static Gtk.MenuItem MakeMenuItem (Gtk.Menu menu, string label, string image_name, EventHandler e, bool enabled)
 	{
 		Gtk.ImageMenuItem i = new Gtk.ImageMenuItem (label);
 		i.Activated += e;
@@ -291,9 +293,11 @@ class GtkUtil {
 		
 		menu.Append (i);
 		i.Show ();
+
+        return i;
 	}
 
-	public static void MakeCheckMenuItem (Gtk.Menu menu, string label, EventHandler e, bool enabled, bool active, bool as_radio)
+	public static Gtk.MenuItem MakeCheckMenuItem (Gtk.Menu menu, string label, EventHandler e, bool enabled, bool active, bool as_radio)
 	{
 		Gtk.CheckMenuItem i = new Gtk.CheckMenuItem (label);
 		i.Activated += e;
@@ -303,6 +307,8 @@ class GtkUtil {
 
 		menu.Append(i);
 		i.Show ();
+
+        return i;
 	}
 
 	public static void MakeMenuSeparator (Gtk.Menu menu)
@@ -370,9 +376,33 @@ class GtkUtil {
 		}
 		return null;
 	}
+}
 
-	
-			
+public class SizeUtil {
+	public static string ToHumanReadable (long size)
+	{
+		string tmp_str = "";
+		float tmp_size = size;
+		int k = 0;
+		string[] size_abr = {"bytes", "kB", "MB", "GB", "TB" };
+		
+		while (tmp_size > 700) { //it's easier to read 0.9MB than 932kB
+			tmp_size = tmp_size / 1024;
+				k++;
+		}
+		
+		if (tmp_size < 7)
+			tmp_str = tmp_size.ToString ("0.##");
+		else if (tmp_size < 70)
+			tmp_str = tmp_size.ToString ("##.#");
+		else
+			tmp_str = tmp_size.ToString ("#,###");
+		
+		if (k < size_abr.Length)
+			return tmp_str + " " + size_abr[k];
+		else
+				return size.ToString();
+	}
 }
 
 class GnomeUtil {
